==> migrate_wizard-2.0.7-alpha1.tar.gz: migrate_wizard/src/Plugin/FieldTypeMW/FieldTypeMWWorkbenchAccessNode.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\field\Entity\FieldStorageConfig;
use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'workbench_access_node' field type.
 *
 * @FieldType(
 *   id = "workbench_access_node",
 * )
 */
class FieldTypeMWWorkbenchAccessNode extends FieldTypeMWBase {

  public static function getMigrationConfig(&$wildcard_yml_config, $origin_field, $data_field, $type_source, $config, $entityFieldManager, $fieldTypeMWManager, $field_collection = NULL): void {

    $wildcard_yml_config['process'][$data_field['destiny']][] = [
      'plugin' => 'skip_on_empty',
      'source' => 'access_id',
      'method' => 'process',
    ];
    $wildcard_yml_config['process'][$data_field['destiny']][] = [
      'plugin' => 'migration_lookup',
      'migration' => $data_field["migration_lookup"],
      'no_stub' => TRUE,
    ];
    $wildcard_yml_config['migration_dependencies']['required'][] = $data_field["migration_lookup"];
  }

  public function addQueryByType($alias, $table, $data_field, $wildcard, $translation): void {
    $wildcard->query->leftJoin('workbench_access_node', 'workbench_access_node', "{$wildcard->getValue('leftJoinTable')} = workbench_access_node.nid");
    $wildcard->query->fields('workbench_access_node', ['access_id']);
    $wildcard->query->groupBy('access_id');
  }
}

==> migrate_wizard-2.0.10-alpha1.tar.gz: migrate_wizard/src/Plugin/FieldTypeMW/FieldTypeMWWorkbenchAccessNode.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'workbench_access_node' field type.
 *
 * @FieldType(
 *     id="workbench_access_node",
 * )
 */
class FieldTypeMWWorkbenchAccessNode extends FieldTypeMWBase {

  public function addQueryByType($alias, $table, $data_field, $wildcard, $translation): void {
    $wildcard->query->leftJoin('workbench_access_node', 'workbench_access_node', "{$wildcard->getValue('leftJoinTable')} = workbench_access_node.nid");
    $wildcard->query->fields('workbench_access_node', ['access_id']);
    $wildcard->query->groupBy('access_id');
  }

  public static function getMigrationConfig(&$wildcard_yml_config, $origin_field, $data_field, $type_source, $config, $entityFieldManager, $fieldTypeMWManager, $field_collection = NULL): void {
    $wildcard_yml_config['process'][$data_field['destiny']][] = [
      'plugin' => 'skip_on_empty',
      'source' => 'access_id',
      'method' => 'process',
    ];
    $wildcard_yml_config['process'][$data_field['destiny']][] = [
      'plugin' => 'migration_lookup',
      'migration' => $data_field['migration_lookup'],
      'no_stub' => TRUE,
    ];
    $wildcard_yml_config['migration_dependencies']['required'][] = $data_field['migration_lookup'];
  }

}
